# Differentiable RHEED simulations in JAX

---

[![PyPI version](https://badge.fury.io/py/rheedium.svg)](https://badge.fury.io/py/rheedium)
[![PyPI Downloads](https://static.pepy.tech/badge/rheedium)](https://pepy.tech/projects/rheedium)
[![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT)
[![Documentation Status](https://readthedocs.org/projects/rheedium/badge/?version=latest)](https://rheedium.readthedocs.io/en/latest/?badge=latest)
[![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.14757400.svg)](https://doi.org/10.5281/zenodo.14757400)

---

The aim of this project is to write RHEED simulations in [JAX](https://github.com/google/jax) so that it's end to end differentiable.

This will install the package as `rheedium`, which is the package that all the codes are.

The codes themselves are in the _src_ directory, following the modern toml convention as the _rheedium_ folder.